==> clevertap-react-native-1.2.1.tgz: package/README.md <==
<p align="center">
 <img src="https://github.com/CleverTap/clevertap-ios-sdk/blob/master/docs/images/clevertap-logo.png" width = "50%"/>
</p>

# CleverTap React Native SDK
[![npm version](https://badge.fury.io/js/clevertap-react-native.svg)](https://badge.fury.io/js/clevertap-react-native)
<a href="https://github.com/CleverTap/clevertap-react-native/releases">
    <img src="https://img.shields.io/github/release/CleverTap/clevertap-react-native.svg" />
</a>
[![npm downloads](https://img.shields.io/npm/dm/clevertap-react-native.svg)](https://www.npmjs.com/package/clevertap-react-native)

## 👋 Introduction
The CleverTap React Native SDK for Mobile Customer Engagement and Analytics solutions.

For more information check out our [website](https://clevertap.com/ "CleverTap")  and  [documentation](https://developer.clevertap.com/docs/ "CleverTap Technical Documentation").

To get started, sign up [here](https://clevertap.com/live-product-demo/).

## 🚀 Install and Integration
1. `npm install --save clevertap-react-native`
2. Follow the [install instructions](./docs/install.md)
3. Follow the [integration instructions](./docs/integration.md)

## 📚 Additional Resources
- [CleverTap iOS SDK Integration guide](https://support.clevertap.com/docs/ios/getting-started.html)
- [CleverTap Android SDK Integration guide](https://support.clevertap.com/docs/android/getting-started.html)

## 📲 CleverTap iOS Push Templates SDK

CleverTap Push Templates SDK helps you engage with your users using fancy push notification templates built specifically to work with [CleverTap Push Templates SDK](https://github.com/CleverTap/CTNotificationContent).
Find the integration steps for the CleverTap Push Templates SDK [here](./docs/iospushtemplates.md)

## 📑 Documentation & Example

- [See the CleverTap React Native Usage Documentation](/docs/usage.md)

- [See the included Example Project](/Example/)


## 🆕 Changelog

Refer to the [CleverTap React Native SDK Change Log](/CHANGELOG.md).

## ⁉️ Help and Questions?

 If you have questions or concerns, you can reach out to the CleverTap support team from the CleverTap Dashboard.

==> clevertap-react-native-3.6.0.tgz: package/README.md <==
<p align="center">
 <img src="https://github.com/CleverTap/clevertap-ios-sdk/blob/master/docs/images/clevertap-logo.png" width = "50%"/>
</p>

# CleverTap React Native SDK
[![npm version](https://badge.fury.io/js/clevertap-react-native.svg)](https://badge.fury.io/js/clevertap-react-native)
<a href="https://github.com/CleverTap/clevertap-react-native/releases">
    <img src="https://img.shields.io/github/release/CleverTap/clevertap-react-native.svg" />
</a>
[![npm downloads](https://img.shields.io/npm/dm/clevertap-react-native.svg)](https://www.npmjs.com/package/clevertap-react-native)

## 👋 Introduction
The CleverTap React Native SDK for Mobile Customer Engagement and Analytics solutions.

For more information check out our [website](https://clevertap.com/ "CleverTap")  and  [documentation](https://developer.clevertap.com/docs/ "CleverTap Technical Documentation").

To get started, sign up [here](https://clevertap.com/live-product-demo/).

## 🚀 Install and Integration
1. `npm install --save clevertap-react-native`
2. Follow the [install instructions](./docs/install.md)
3. Follow the [integration instructions](./docs/integration.md)

## 📚 Additional Resources
- [CleverTap iOS SDK Integration guide](https://developer.clevertap.com/docs/ios)
- [CleverTap Android SDK Integration guide](https://developer.clevertap.com/docs/android)

## 📲 CleverTap iOS Push Templates SDK

CleverTap Push Templates SDK helps you engage with your users using fancy push notification templates built specifically to work with [CleverTap Push Templates SDK](https://github.com/CleverTap/CTNotificationContent).
Find the integration steps for the CleverTap Push Templates SDK [here](./docs/iospushtemplates.md)

## ℹ️ Version Support
| CleverTap RN SDK | React Native | Supports New Architecture? |
|------------------|--------------|----------------------------|
| 3.0.0+           | >=0.65       | ✅ (>=0.71)                 |
| <=2.2.1          | >=0.49.5     | ❌                          |

## 📑 Documentation & Example

- [See the CleverTap React Native Usage Documentation](/docs/usage.md)

- [See the included Example Project](/Example/)


## 🆕 Changelog

Refer to the [CleverTap React Native SDK Change Log](/CHANGELOG.md).

## ⁉️ Help and Questions?

 If you have questions or concerns, you can reach out to the CleverTap support team from the CleverTap Dashboard.
